# Jellyfin CLI

##### A Jellyfin command line client written in Python with urwid.  
![Image](https://i.imgur.com/I3Nbd3R.png)
----

### How to install  
This app requires Python3.6 or higher  
You can install it by executing `pip3 install --user jellyfin-cli`  
You will also need to install MPV. 
I recommend symlinking the script to your path so you can execute it directly from the terminal:
This will typically require something like the following:
`ln -s $HOME/.local/bin/jellyfin-cli /usr/bin/jellyfin-cli`

### How to use
The first time you run it, you will be greeted by a minimalist login prompt. This will repeat every time the token is invalidated.
After that you can use the interface.
### Development

Want to contribute? Sure! You are free to create bug reports, feature requests and pull requests. I will try my best to review all of them.
